import React, { useState, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { csv, scaleLinear, scaleBand, max } from 'd3';

const width = 960;
const height = 500;

const csvUrl = 'https://gist.githubusercontent.com/blessedaim/194e3ffc1852220dcd762edf4d9768c0/raw/49bc369907064b312e0c235f112162d9dc9f31b0/UN_Population_2019.csv'
const App = () => {
  const [data, setData] = useState(null);
  
  useEffect(() => {
    const row = d => {
    	d.Population = +d['2020'];
      return d;
    }
  	csv(csvUrl, row).then(data => {
      setData(data.slice(0,10));
    });
  }, []);
 
  if (!data) {
    return <pre>Loading..</pre>;
  }
  
  const xScale = scaleLinear().domain([0, max(data, d => d.Population)]).range([0, width]);
  const yScale = scaleBand().domain(data.map(d => d.Country)).range([0, height]);
	return (
  	<svg width={width} height={height}>
      {data.map(d => <rect
                       x={0}
                       y={yScale(d.Country)}
                       width={xScale(d.Population)}
                       height={yScale.bandwidth()}
                       />
          )}
    </svg>
    );
};

ReactDOM.render(<App />, document.getElementById('root'));
